<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>DialogGraph</name>
    <message>
        <location filename="../ui/graphDialog.ui" line="14"/>
        <source>Graph</source>
        <translation>Grafico</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="23"/>
        <source>Please wait ...</source>
        <translation>Attendere prego...</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="70"/>
        <location filename="../ui/graphDialog.ui" line="73"/>
        <source>Zoom Out</source>
        <translation>Zoom indietro</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="93"/>
        <location filename="../ui/graphDialog.ui" line="96"/>
        <source>Zoom In</source>
        <translation>Zoom In</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="123"/>
        <source>Number of levels:</source>
        <translation>Numero di livelli:</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="153"/>
        <location filename="../ui/graphDialog.ui" line="156"/>
        <location filename="../ui/graphDialog.ui" line="159"/>
        <source>Save to DOT file</source>
        <translation>Salvare file DOT</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="172"/>
        <location filename="../ui/graphDialog.ui" line="175"/>
        <location filename="../ui/graphDialog.ui" line="178"/>
        <source>Save Image</source>
        <translation>Salva immagine</translation>
    </message>
    <message>
        <location filename="../ui/graphDialog.ui" line="191"/>
        <location filename="../ui/graphDialog.ui" line="194"/>
        <location filename="../ui/graphDialog.ui" line="197"/>
        <source>Close</source>
        <translation>Chiudere</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainWindow.ui" line="14"/>
        <source>CodeQuery</source>
        <translation>CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="27"/>
        <location filename="../ui/mainWindow.ui" line="30"/>
        <source>Open Database</source>
        <translation>Database aperto</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="76"/>
        <source>Auto-complete</source>
        <translation>Completamento automatico</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="90"/>
        <source>Exact match</source>
        <translation>Corrispondenza esatta</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="104"/>
        <location filename="../ui/mainWindow.ui" line="107"/>
        <source>File path filter</source>
        <translation>Filtro percorso file</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="110"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="126"/>
        <location filename="../ui/mainWindow.ui" line="129"/>
        <source>File path filter, wildcard searches (* and ?) are supported</source>
        <translation>Filtro percorso file, ricerche con caratteri jolly (* e?) sono supportati</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="152"/>
        <location filename="../ui/mainWindow.ui" line="155"/>
        <source>Previous search term</source>
        <translation>Termine di ricerca precedente</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="175"/>
        <location filename="../ui/mainWindow.ui" line="178"/>
        <source>Next search term</source>
        <translation>Successivo al termine di ricerca</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="204"/>
        <location filename="../ui/mainWindow.ui" line="207"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>Se la corrispondenza esatta è spento, ricerche con caratteri jolly (* e?) sono supportati</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="226"/>
        <location filename="../ui/mainWindow.ui" line="229"/>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="249"/>
        <location filename="../ui/mainWindow.ui" line="252"/>
        <source>Paste and Search</source>
        <translation>Incolla e ricerca</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="275"/>
        <location filename="../ui/mainWindow.ui" line="278"/>
        <source>Draw graph</source>
        <translation>Disegnare il grafico</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="335"/>
        <location filename="../ui/mainWindow.ui" line="338"/>
        <source>Previous File</source>
        <translation>Precedente File</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="358"/>
        <location filename="../ui/mainWindow.ui" line="361"/>
        <source>Next File</source>
        <translation>File successivo</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="381"/>
        <location filename="../ui/mainWindow.ui" line="384"/>
        <source>Open in Editor</source>
        <translation>Aperto nell&apos;Editor</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="404"/>
        <location filename="../ui/mainWindow.ui" line="407"/>
        <source>Go to selected line</source>
        <translation>Vai alla riga selezionata.</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="427"/>
        <location filename="../ui/mainWindow.ui" line="430"/>
        <source>Reduce font size</source>
        <translation>Ridurre la dimensione del carattere</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="450"/>
        <location filename="../ui/mainWindow.ui" line="453"/>
        <source>Increase font size</source>
        <translation>Aumentare la dimensione del carattere</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="480"/>
        <location filename="../ui/mainWindow.ui" line="483"/>
        <source>Copy, paste and search</source>
        <translation>Copia, incolla e ricerca</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="503"/>
        <location filename="../ui/mainWindow.ui" line="506"/>
        <source>Symbol search only for paste and search</source>
        <translation>Simbolo cerca solo pasta e ricerca</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="509"/>
        <source>Symbol only</source>
        <translation>Unico simbolo</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="523"/>
        <location filename="../ui/mainWindow.ui" line="526"/>
        <source>Previous search result in this file</source>
        <translation>Risultato della ricerca precedente in questo file</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="546"/>
        <location filename="../ui/mainWindow.ui" line="549"/>
        <source>Next search result in this file</source>
        <translation>Risultati di ricerca successivo in questo file</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="581"/>
        <source>FilePath:0</source>
        <translation>FilePath:0</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="610"/>
        <source>Sort by line number</source>
        <translation>Ordina per numero di riga</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="615"/>
        <source>Sort by name</source>
        <translation>Ordina per nome</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="665"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="672"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="680"/>
        <source>Help</source>
        <translation>Guida</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="692"/>
        <source>Exit</source>
        <translation>Uscita</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="700"/>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="705"/>
        <source>About</source>
        <translation>Info su</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="710"/>
        <source>External Editor</source>
        <translation>Editor esterno</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="715"/>
        <source>Open CQ Database</source>
        <translation>CQ Open Database</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="720"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="725"/>
        <source>About Qt</source>
        <translation>Info su Qt</translation>
    </message>
    <message>
        <location filename="../ui/mainWindow.ui" line="733"/>
        <source>File Viewer Settings</source>
        <translation>Impostazioni del file Viewer</translation>
    </message>
</context>
<context>
    <name>aboutDialog</name>
    <message>
        <location filename="../ui/aboutDialog.ui" line="20"/>
        <source>About CodeQuery</source>
        <translation>Info su CodeQuery</translation>
    </message>
    <message>
        <location filename="../ui/aboutDialog.ui" line="116"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>cqDialogGraph</name>
    <message>
        <location filename="../graphdialog.cpp" line="89"/>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="92"/>
        <source>Export Image</source>
        <translation>Esportazione immagine</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="103"/>
        <location filename="../graphdialog.cpp" line="122"/>
        <source>File could not be saved!</source>
        <translation>File non poteva essere salvato!</translation>
    </message>
    <message>
        <location filename="../graphdialog.cpp" line="111"/>
        <source>Export DOT file</source>
        <translation>Esportare file DOT</translation>
    </message>
</context>
<context>
    <name>fileViewSettingsDialog</name>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="14"/>
        <source>File Viewer Settings</source>
        <translation>Impostazioni del file Viewer</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="33"/>
        <source>Font</source>
        <translation>Tipo di carattere</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="46"/>
        <source>Syntax highlight theme</source>
        <translation>Tema di evidenziazione sintassi</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="59"/>
        <source>Tab Width (number of spaces)</source>
        <translation>Larghezza scheda (numero di spazi)</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="119"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../ui/fileViewSettingsDialog.ui" line="132"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>fileviewer</name>
    <message>
        <location filename="../fileviewer.cpp" line="249"/>
        <source>File not found</source>
        <translation>File non trovato</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="256"/>
        <source>File could not be opened</source>
        <translation>File non può essere aperto</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="270"/>
        <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
        <translation>Il file di origine per essere visualizzati è più recente rispetto al file di database CodeQuery. Si raccomanda di rigenerare manualmente il file di database CodeQuery.</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="533"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="534"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="536"/>
        <source>External Editor Configuration</source>
        <translation>Configurazione Editor esterno</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="537"/>
        <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
        <translation>Inserisci il percorso e gli argomenti per l&apos;editor esterno. Sostituire come segue:</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="539"/>
        <source>for file path</source>
        <translation>per il percorso del file</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="541"/>
        <source>for line number</source>
        <translation>per numero di riga</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="543"/>
        <source>For example:</source>
        <translation>Ad esempio:</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="568"/>
        <source>File could not be opened!</source>
        <translation>File non può essere aperto!</translation>
    </message>
    <message>
        <location filename="../fileviewer.cpp" line="593"/>
        <source>External editor could not be started. Please check Options!</source>
        <translation>Editor esterno potrebbe non essere avviato. Si prega di controllare le opzioni!</translation>
    </message>
</context>
<context>
    <name>listhandler</name>
    <message>
        <location filename="../listhandler.cpp" line="129"/>
        <source>Symbol</source>
        <translation>Simbolo</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="130"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="133"/>
        <source>Line</source>
        <translation>Linea</translation>
    </message>
    <message>
        <location filename="../listhandler.cpp" line="133"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
</context>
<context>
    <name>mainwindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Select language:</source>
        <translation>Seleziona lingua:</translation>
    </message>
</context>
<context>
    <name>searchhandler</name>
    <message>
        <location filename="../searchhandler.cpp" line="334"/>
        <source>Symbol</source>
        <translation>Simbolo</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="337"/>
        <source>Function or macro definition (Graph available)</source>
        <translation>Definizione di funzione o macro (grafico disponibile)</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="349"/>
        <source>Class or struct (Graph available)</source>
        <translation>Classe o struttura (grafico disponibile)</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="343"/>
        <source>Functions calling this function</source>
        <translation>Funzioni di chiamata a questa funzione</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="346"/>
        <source>Functions called by this function</source>
        <translation>Funzioni chiamate da questa funzione</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="340"/>
        <source>Calls of this function or macro</source>
        <translation>Chiamate di questa funzione o macro</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="352"/>
        <source>Class which owns this member or method</source>
        <translation>Classe che possiede questo membro o metodo.</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="355"/>
        <source>Members or methods of this class</source>
        <translation>Membri o i metodi di questa classe</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="358"/>
        <source>Parent of this class</source>
        <translation>Padre di questa classe</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="361"/>
        <source>Children of this class</source>
        <translation>Bambini di questa classe</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="364"/>
        <source>Files including this file</source>
        <translation>File incluso questo file</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="367"/>
        <source>Full path for file</source>
        <translation>Percorso completo per il file</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="370"/>
        <source>Functions or macros inside this file</source>
        <translation>Macro o funzioni all&apos;interno di questo file.</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="381"/>
        <source>CodeQuery DB Files</source>
        <translation>CodeQuery DB file</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="384"/>
        <source>Open CQ database file</source>
        <translation>Aprire il file database CQ</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="453"/>
        <source>Function Call Graph</source>
        <translation>Funzione Call Graph</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="457"/>
        <source>Class Inheritance Graph</source>
        <translation>Grafico di ereditarietà di classe</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="473"/>
        <location filename="../searchhandler.cpp" line="476"/>
        <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
        <translation>Se la corrispondenza esatta è spento, ricerche con caratteri jolly (* e?) sono supportati</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="548"/>
        <source>results found</source>
        <translation>risultati trovati</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="567"/>
        <source>in progress</source>
        <translation>in corso</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="568"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="665"/>
        <source>You have to first select an item from the list before pushing the Graph button.</source>
        <translation>È necessario innanzitutto selezionare un elemento dall&apos;elenco prima di spingere il pulsante grafico.</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="794"/>
        <source>File open error</source>
        <translation>Errore di file aperti</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="795"/>
        <source>Wrong file format</source>
        <translation>Formato di file sbagliato</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="796"/>
        <source>Incorrect CQ database version</source>
        <translation>Versione del database corretto CQ</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="797"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../searchhandler.cpp" line="799"/>
        <source>Unknown Error</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
</TS>
